@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-history.h,v 1.16 2006/09/13 11:34:13 chpe Exp $
+ *  $Id: ephy-history.h 7244 2007-08-06 09:16:45Z diegoe $
  */
 
 #ifndef EPHY_HISTORY_H
@@ -120,6 +120,9 @@ void            ephy_history_clear              (EphyHistory *gh);
 
 gboolean	ephy_history_is_enabled		(EphyHistory *history);
 
+void		ephy_history_set_enabled	(EphyHistory *history,
+						 gboolean enabled);
+
 G_END_DECLS
 
 #endif
