@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.86 2006/10/15 14:05:39 wbolster Exp $
+ * $Id: MozDownload.cpp 7158 2007-07-14 22:20:22Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -323,6 +323,10 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 		}
 		else if (NS_SUCCEEDED (aStatus))
 		{
+			/* see http://bugzilla.gnome.org/show_bug.cgi?id=456945 */
+#ifdef HAVE_GECKO_1_9
+			return NS_OK;
+#else
 			GnomeVFSMimeApplication *helperApp;
 			nsCString mimeType;
 			rv = mMIMEInfo->GetMIMEType (mimeType);
@@ -374,6 +378,7 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 
 				g_strfreev (str);
 			}
+#endif /* HAVE_GECKO_1_9 */
 		}
 	}
         
@@ -444,6 +449,20 @@ MozDownload::OnProgressChange64 (nsIWebProgress *aWebProgress,
 	return NS_OK;
 }
 
+#ifdef HAVE_GECKO_1_9
+/* boolean onRefreshAttempted (in nsIWebProgress aWebProgress, in nsIURI aRefreshURI, in long aDelay, in boolean aSameURI); */
+NS_IMETHODIMP
+MozDownload::OnRefreshAttempted(nsIWebProgress *aWebProgress,
+                                nsIURI *aUri,
+                                PRInt32 aDelay,
+                                PRBool aSameUri,
+                                PRBool *allowRefresh)
+{
+        *allowRefresh = PR_TRUE;
+        return NS_OK;
+}
+#endif
+
 NS_IMETHODIMP
 MozDownload::OnLocationChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest, nsIURI *location)
 {
@@ -619,19 +638,24 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 		nsCString cPath;
 		inDestFile->GetNativePath (cPath);
 
-		GString *path = g_string_new (cPath.get());
-		char *dot_pos = strchr (path->str, '.');
+		char *basename = g_path_get_basename (cPath.get());
+		char *dirname = g_path_get_dirname (cPath.get());
+		char *dot_pos = strchr (basename, '.');
 		if (dot_pos)
 		{
-			g_string_truncate (path, dot_pos - path->str);
+			*dot_pos = 0;
 		}
-		g_string_append (path, " ");
-		g_string_append (path, _("Files"));
+		/* translators: this is the directory name to store auxilary files when saving html files */
+		char *new_basename = g_strdup_printf (_("%s Files"), basename);
+		char *new_path = g_build_filename (dirname, new_basename, NULL);
+		g_free (new_basename);
+		g_free (basename);
+		g_free (dirname);
       
 		filesFolder = do_CreateInstance ("@mozilla.org/file/local;1");
-		filesFolder->InitWithNativePath (nsCString(path->str));
+		filesFolder->InitWithNativePath (nsCString(new_path));
 
-		g_string_free (path, TRUE);
+		g_free (new_path);
 
 		rv = webPersist->SaveDocument (domDocument, inDestFile, filesFolder,
 					       contentType, encodingFlags, 80);
